@@ -1,10 +1,4 @@
-package MooseX::Singleton;
-BEGIN {
-  $MooseX::Singleton::AUTHORITY = 'cpan:SARTAK';
-}
-{
-  $MooseX::Singleton::VERSION = '0.29';
-}
+package MooseX::Singleton; # git description: 0.25-37-g820a8b5
 
 use Moose 1.10 ();
 use Moose::Exporter;
@@ -12,6 +6,7 @@ use MooseX::Singleton::Role::Object;
 use MooseX::Singleton::Role::Meta::Class;
 use MooseX::Singleton::Role::Meta::Instance;
 
+our $VERSION = '0.30';
 
 Moose::Exporter->setup_import_methods( also => 'Moose' );
 
@@ -46,19 +41,21 @@ sub init_meta {
 
 1;
 
-# ABSTRACT: turn your Moose class into a singleton
-
+# ABSTRACT: Turn your Moose class into a singleton
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-MooseX::Singleton - turn your Moose class into a singleton
+MooseX::Singleton - Turn your Moose class into a singleton
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
@@ -115,35 +112,74 @@ This method currently works like a hybrid of C<initialize> and
 C<instance>. However, calling C<new> directly will probably be deprecated in a
 future release. Instead, call C<initialize> or C<instance> as appropriate.
 
-=head1 BUGS
-
-Please report any bugs or feature requests to
-C<bug-moosex-singleton@rt.cpan.org>, or through the web interface at
-L<http://rt.cpan.org>. We will be notified, and then you'll automatically be
-notified of progress on your bug as we make changes.
+=for Pod::Coverage init_meta
 
 =head1 SOME CODE STOLEN FROM
 
+=for stopwords Anders
+
 Anders Nor Berle E<lt>debolaz@gmail.comE<gt>
 
 =head1 AND PATCHES FROM
 
 Ricardo SIGNES E<lt>rjbs@cpan.orgE<gt>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Singleton>
+(or L<bug-MooseX-Singleton@rt.cpan.org|mailto:bug-MooseX-Singleton@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
-Shawn M Moore <sartak@gmail.com>
+Shawn M Moore <code@sartak.org>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Dave Rolsky Karen Etheridge Ricardo SIGNES Kaare Rasmussen Anders Nor Berle Jonathan Rockway Hans Dieter Pearcey
+
+=over 4
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=item *
+
+Kaare Rasmussen <kaare@jasonic.dk>
+
+=item *
+
+Anders Nor Berle <berle@cpan.org>
+
+=item *
+
+Jonathan Rockway <jon@jrock.us>
+
+=item *
+
+Hans Dieter Pearcey <hdp@weftsoar.net>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011 by Shawn M Moore.
+This software is copyright (c) 2007 by Shawn M Moore.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
